@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.17';
+$VERSION = '0.19';
 
 #--------------------------------------------------------------------------
 
@@ -245,7 +245,7 @@ sub convert {
 
     # complete and submit the form
     $web->submit_form(
-            form_name => 'ucc',
+            form_number => 2,
             fields    => { 'From'   => $params{source},
                            'To'     => $params{target},
                            'Amount' => $params{value} } );
